@@ -41,10 +41,11 @@
 
 static int verbosity = 1;
 
-static char * G_GNUC_FORMAT (1)
-format_as_comment (const char *format)
+/* @freeme is a workaround for Clang; see gnome-terminal bug 790318. */
+static char * G_GNUC_FORMAT (2)
+format_as_comment (char** freeme, const char *format)
 {
-  return g_strdup_printf ("# %s", format);
+  return *freeme = g_strdup_printf ("# %s", format);
 }
 
 void
@@ -56,10 +57,10 @@ terminal_fprintf (FILE* fp,
         if (verbosity < verbosity_level)
                 return;
 
-        gs_free char *commented_format = format_as_comment (format);
+        gs_free char* freeme;
         va_list args;
         va_start(args, format);
-        g_vfprintf(fp, commented_format, args);
+        g_vfprintf(fp, format_as_comment(&freeme, format), args);
         va_end(args);
 }
 
@@ -316,13 +317,12 @@ option_version_cb (const gchar *option_name,
                    gpointer     data,
                    GError     **error)
 {
-  terminal_print ("%s %s ", _("GNOME Terminal"), VERSION);
-  terminal_print (_("Using VTE version %u.%u.%u"),
+  terminal_print ("GNOME Terminal %s using VTE %u.%u.%u %s\n",
+                  VERSION,
                   vte_get_major_version (),
                   vte_get_minor_version (),
-                  vte_get_micro_version ());
-  terminal_print (" %s\n", vte_get_features ());
-
+                  vte_get_micro_version (),
+                  vte_get_features ());
   exit (EXIT_SUCCESS);
 }
 
